@@ -13,6 +13,7 @@ use HTTP::Response;
 use HTTP::Status ();
 use Mojo::Message::Request;
 use Mojo::Message::Response;
+use YAML::XS 0.87;
 
 # type can be
 # 'lwp': classes of type URI, HTTP::Headers, HTTP::Request, HTTP::Response
@@ -89,4 +90,18 @@ sub uri ($uri_string, @path_parts) {
   return $uri;
 }
 
+# create a Result object out of the document errors; suitable for stringifying
+# as the OpenAPI::Modern constructor might do.
+sub document_result ($document) {
+  JSON::Schema::Modern::Result->new(
+    valid => $document->has_errors,
+    errors => [ $document->errors ],
+  );
+}
+
+sub yaml ($string) {
+  local $YAML::XS::Boolean = 'JSON::PP';
+  Load(Encode::encode('UTF-8', $string));
+}
+
 1;
